""" - Type Stubs

Auto-generated stub file for type checking and IDE support.

Endpoint: firewall/vip6
Category: cmdb
"""

from __future__ import annotations

from typing import (
    Any,
    ClassVar,
    Literal,
    TypedDict,
    overload,
)

from hfortix_fortios.models import (
    FortiObject,
    FortiObjectList,
)


# ================================================================
# TypedDict Payloads
# ================================================================

class Vip6RealserversMonitorItem(TypedDict, total=False):
    """Nested item for realservers.monitor field."""
    name: str


class Vip6SrcfilterItem(TypedDict, total=False):
    """Nested item for src-filter field."""
    range: str


class Vip6QuicDict(TypedDict, total=False):
    """Nested object type for quic field."""
    max_idle_timeout: int
    max_udp_payload_size: int
    active_connection_id_limit: int
    ack_delay_exponent: int
    max_ack_delay: int
    max_datagram_frame_size: int
    active_migration: Literal["enable", "disable"]
    grease_quic_bit: Literal["enable", "disable"]


class Vip6RealserversItem(TypedDict, total=False):
    """Nested item for realservers field."""
    id: int
    ip: str
    port: int
    status: Literal["active", "standby", "disable"]
    weight: int
    holddown_interval: int
    healthcheck: Literal["disable", "enable", "vip"]
    http_host: str
    translate_host: Literal["enable", "disable"]
    max_connections: int
    monitor: str | list[str] | list[Vip6RealserversMonitorItem]
    client_ip: str
    verify_cert: Literal["enable", "disable"]


class Vip6SslcertificateItem(TypedDict, total=False):
    """Nested item for ssl-certificate field."""
    name: str


class Vip6SslciphersuitesItem(TypedDict, total=False):
    """Nested item for ssl-cipher-suites field."""
    priority: int
    cipher: Literal["TLS-AES-128-GCM-SHA256", "TLS-AES-256-GCM-SHA384", "TLS-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-AES-128-CBC-SHA", "TLS-RSA-WITH-AES-256-CBC-SHA", "TLS-RSA-WITH-AES-128-CBC-SHA256", "TLS-RSA-WITH-AES-128-GCM-SHA256", "TLS-RSA-WITH-AES-256-CBC-SHA256", "TLS-RSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-SEED-CBC-SHA", "TLS-DHE-DSS-WITH-SEED-CBC-SHA", "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384", "TLS-RSA-WITH-SEED-CBC-SHA", "TLS-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-RC4-128-SHA", "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-RC4-128-MD5", "TLS-RSA-WITH-RC4-128-SHA", "TLS-DHE-RSA-WITH-DES-CBC-SHA", "TLS-DHE-DSS-WITH-DES-CBC-SHA", "TLS-RSA-WITH-DES-CBC-SHA"]
    versions: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]


class Vip6SslserverciphersuitesItem(TypedDict, total=False):
    """Nested item for ssl-server-cipher-suites field."""
    priority: int
    cipher: Literal["TLS-AES-128-GCM-SHA256", "TLS-AES-256-GCM-SHA384", "TLS-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-AES-128-CBC-SHA", "TLS-RSA-WITH-AES-256-CBC-SHA", "TLS-RSA-WITH-AES-128-CBC-SHA256", "TLS-RSA-WITH-AES-128-GCM-SHA256", "TLS-RSA-WITH-AES-256-CBC-SHA256", "TLS-RSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-SEED-CBC-SHA", "TLS-DHE-DSS-WITH-SEED-CBC-SHA", "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384", "TLS-RSA-WITH-SEED-CBC-SHA", "TLS-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-RC4-128-SHA", "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-RC4-128-MD5", "TLS-RSA-WITH-RC4-128-SHA", "TLS-DHE-RSA-WITH-DES-CBC-SHA", "TLS-DHE-DSS-WITH-DES-CBC-SHA", "TLS-RSA-WITH-DES-CBC-SHA"]
    versions: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]


class Vip6MonitorItem(TypedDict, total=False):
    """Nested item for monitor field."""
    name: str


class Vip6Payload(TypedDict, total=False):
    """Payload type for Vip6 operations."""
    name: str
    id: int
    uuid: str
    comment: str
    type: Literal["static-nat", "server-load-balance", "access-proxy"]
    src_filter: str | list[str] | list[Vip6SrcfilterItem]
    src_vip_filter: Literal["disable", "enable"]
    extip: str
    mappedip: str
    nat_source_vip: Literal["disable", "enable"]
    ndp_reply: Literal["disable", "enable"]
    portforward: Literal["disable", "enable"]
    protocol: Literal["tcp", "udp", "sctp"]
    extport: str
    mappedport: str
    color: int
    ldb_method: Literal["static", "round-robin", "weighted", "least-session", "least-rtt", "first-alive", "http-host"]
    server_type: Literal["http", "https", "imaps", "pop3s", "smtps", "ssl", "tcp", "udp", "ip"]
    http_redirect: Literal["enable", "disable"]
    persistence: Literal["none", "http-cookie", "ssl-session-id"]
    h2_support: Literal["enable", "disable"]
    h3_support: Literal["enable", "disable"]
    quic: Vip6QuicDict
    nat66: Literal["disable", "enable"]
    nat64: Literal["disable", "enable"]
    add_nat64_route: Literal["disable", "enable"]
    empty_cert_action: Literal["accept", "block", "accept-unmanageable"]
    user_agent_detect: Literal["disable", "enable"]
    client_cert: Literal["disable", "enable"]
    realservers: str | list[str] | list[Vip6RealserversItem]
    http_cookie_domain_from_host: Literal["disable", "enable"]
    http_cookie_domain: str
    http_cookie_path: str
    http_cookie_generation: int
    http_cookie_age: int
    http_cookie_share: Literal["disable", "same-ip"]
    https_cookie_secure: Literal["disable", "enable"]
    http_multiplex: Literal["enable", "disable"]
    http_ip_header: Literal["enable", "disable"]
    http_ip_header_name: str
    outlook_web_access: Literal["disable", "enable"]
    weblogic_server: Literal["disable", "enable"]
    websphere_server: Literal["disable", "enable"]
    ssl_mode: Literal["half", "full"]
    ssl_certificate: str | list[str] | list[Vip6SslcertificateItem]
    ssl_dh_bits: Literal["768", "1024", "1536", "2048", "3072", "4096"]
    ssl_algorithm: Literal["high", "medium", "low", "custom"]
    ssl_cipher_suites: str | list[str] | list[Vip6SslciphersuitesItem]
    ssl_server_renegotiation: Literal["enable", "disable"]
    ssl_server_algorithm: Literal["high", "medium", "low", "custom", "client"]
    ssl_server_cipher_suites: str | list[str] | list[Vip6SslserverciphersuitesItem]
    ssl_pfs: Literal["require", "deny", "allow"]
    ssl_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]
    ssl_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]
    ssl_server_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"]
    ssl_server_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"]
    ssl_accept_ffdhe_groups: Literal["enable", "disable"]
    ssl_send_empty_frags: Literal["enable", "disable"]
    ssl_client_fallback: Literal["disable", "enable"]
    ssl_client_renegotiation: Literal["allow", "deny", "secure"]
    ssl_client_session_state_type: Literal["disable", "time", "count", "both"]
    ssl_client_session_state_timeout: int
    ssl_client_session_state_max: int
    ssl_client_rekey_count: int
    ssl_server_session_state_type: Literal["disable", "time", "count", "both"]
    ssl_server_session_state_timeout: int
    ssl_server_session_state_max: int
    ssl_http_location_conversion: Literal["enable", "disable"]
    ssl_http_match_host: Literal["enable", "disable"]
    ssl_hpkp: Literal["disable", "enable", "report-only"]
    ssl_hpkp_primary: str
    ssl_hpkp_backup: str
    ssl_hpkp_age: int
    ssl_hpkp_report_uri: str
    ssl_hpkp_include_subdomains: Literal["disable", "enable"]
    ssl_hsts: Literal["disable", "enable"]
    ssl_hsts_age: int
    ssl_hsts_include_subdomains: Literal["disable", "enable"]
    monitor: str | list[str] | list[Vip6MonitorItem]
    max_embryonic_connections: int
    embedded_ipv4_address: Literal["disable", "enable"]
    ipv4_mappedip: str
    ipv4_mappedport: str


# ================================================================
# Response Types (TypedDict for dict-style access)
# ================================================================

class Vip6Response(TypedDict, total=False):
    """Response type for Vip6 - use with .dict property for typed dict access."""
    name: str
    id: int
    uuid: str
    comment: str
    type: Literal["static-nat", "server-load-balance", "access-proxy"]
    src_filter: list[Vip6SrcfilterItem]
    src_vip_filter: Literal["disable", "enable"]
    extip: str
    mappedip: str
    nat_source_vip: Literal["disable", "enable"]
    ndp_reply: Literal["disable", "enable"]
    portforward: Literal["disable", "enable"]
    protocol: Literal["tcp", "udp", "sctp"]
    extport: str
    mappedport: str
    color: int
    ldb_method: Literal["static", "round-robin", "weighted", "least-session", "least-rtt", "first-alive", "http-host"]
    server_type: Literal["http", "https", "imaps", "pop3s", "smtps", "ssl", "tcp", "udp", "ip"]
    http_redirect: Literal["enable", "disable"]
    persistence: Literal["none", "http-cookie", "ssl-session-id"]
    h2_support: Literal["enable", "disable"]
    h3_support: Literal["enable", "disable"]
    quic: Vip6QuicDict
    nat66: Literal["disable", "enable"]
    nat64: Literal["disable", "enable"]
    add_nat64_route: Literal["disable", "enable"]
    empty_cert_action: Literal["accept", "block", "accept-unmanageable"]
    user_agent_detect: Literal["disable", "enable"]
    client_cert: Literal["disable", "enable"]
    realservers: list[Vip6RealserversItem]
    http_cookie_domain_from_host: Literal["disable", "enable"]
    http_cookie_domain: str
    http_cookie_path: str
    http_cookie_generation: int
    http_cookie_age: int
    http_cookie_share: Literal["disable", "same-ip"]
    https_cookie_secure: Literal["disable", "enable"]
    http_multiplex: Literal["enable", "disable"]
    http_ip_header: Literal["enable", "disable"]
    http_ip_header_name: str
    outlook_web_access: Literal["disable", "enable"]
    weblogic_server: Literal["disable", "enable"]
    websphere_server: Literal["disable", "enable"]
    ssl_mode: Literal["half", "full"]
    ssl_certificate: list[Vip6SslcertificateItem]
    ssl_dh_bits: Literal["768", "1024", "1536", "2048", "3072", "4096"]
    ssl_algorithm: Literal["high", "medium", "low", "custom"]
    ssl_cipher_suites: list[Vip6SslciphersuitesItem]
    ssl_server_renegotiation: Literal["enable", "disable"]
    ssl_server_algorithm: Literal["high", "medium", "low", "custom", "client"]
    ssl_server_cipher_suites: list[Vip6SslserverciphersuitesItem]
    ssl_pfs: Literal["require", "deny", "allow"]
    ssl_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]
    ssl_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]
    ssl_server_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"]
    ssl_server_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"]
    ssl_accept_ffdhe_groups: Literal["enable", "disable"]
    ssl_send_empty_frags: Literal["enable", "disable"]
    ssl_client_fallback: Literal["disable", "enable"]
    ssl_client_renegotiation: Literal["allow", "deny", "secure"]
    ssl_client_session_state_type: Literal["disable", "time", "count", "both"]
    ssl_client_session_state_timeout: int
    ssl_client_session_state_max: int
    ssl_client_rekey_count: int
    ssl_server_session_state_type: Literal["disable", "time", "count", "both"]
    ssl_server_session_state_timeout: int
    ssl_server_session_state_max: int
    ssl_http_location_conversion: Literal["enable", "disable"]
    ssl_http_match_host: Literal["enable", "disable"]
    ssl_hpkp: Literal["disable", "enable", "report-only"]
    ssl_hpkp_primary: str
    ssl_hpkp_backup: str
    ssl_hpkp_age: int
    ssl_hpkp_report_uri: str
    ssl_hpkp_include_subdomains: Literal["disable", "enable"]
    ssl_hsts: Literal["disable", "enable"]
    ssl_hsts_age: int
    ssl_hsts_include_subdomains: Literal["disable", "enable"]
    monitor: list[Vip6MonitorItem]
    max_embryonic_connections: int
    embedded_ipv4_address: Literal["disable", "enable"]
    ipv4_mappedip: str
    ipv4_mappedport: str


# ================================================================
# Response Types (Class for attribute access)
# ================================================================


class Vip6RealserversMonitorItemObject(FortiObject[Vip6RealserversMonitorItem]):
    """Typed object for realservers.monitor table items with attribute access."""
    name: str


class Vip6SrcfilterItemObject(FortiObject[Vip6SrcfilterItem]):
    """Typed object for src-filter table items with attribute access."""
    range: str


class Vip6RealserversItemObject(FortiObject[Vip6RealserversItem]):
    """Typed object for realservers table items with attribute access."""
    id: int
    ip: str
    port: int
    status: Literal["active", "standby", "disable"]
    weight: int
    holddown_interval: int
    healthcheck: Literal["disable", "enable", "vip"]
    http_host: str
    translate_host: Literal["enable", "disable"]
    max_connections: int
    monitor: FortiObjectList[Vip6RealserversMonitorItemObject]
    client_ip: str
    verify_cert: Literal["enable", "disable"]


class Vip6SslcertificateItemObject(FortiObject[Vip6SslcertificateItem]):
    """Typed object for ssl-certificate table items with attribute access."""
    name: str


class Vip6SslciphersuitesItemObject(FortiObject[Vip6SslciphersuitesItem]):
    """Typed object for ssl-cipher-suites table items with attribute access."""
    priority: int
    cipher: Literal["TLS-AES-128-GCM-SHA256", "TLS-AES-256-GCM-SHA384", "TLS-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-AES-128-CBC-SHA", "TLS-RSA-WITH-AES-256-CBC-SHA", "TLS-RSA-WITH-AES-128-CBC-SHA256", "TLS-RSA-WITH-AES-128-GCM-SHA256", "TLS-RSA-WITH-AES-256-CBC-SHA256", "TLS-RSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-SEED-CBC-SHA", "TLS-DHE-DSS-WITH-SEED-CBC-SHA", "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384", "TLS-RSA-WITH-SEED-CBC-SHA", "TLS-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-RC4-128-SHA", "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-RC4-128-MD5", "TLS-RSA-WITH-RC4-128-SHA", "TLS-DHE-RSA-WITH-DES-CBC-SHA", "TLS-DHE-DSS-WITH-DES-CBC-SHA", "TLS-RSA-WITH-DES-CBC-SHA"]
    versions: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]


class Vip6SslserverciphersuitesItemObject(FortiObject[Vip6SslserverciphersuitesItem]):
    """Typed object for ssl-server-cipher-suites table items with attribute access."""
    priority: int
    cipher: Literal["TLS-AES-128-GCM-SHA256", "TLS-AES-256-GCM-SHA384", "TLS-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-ECDHE-ECDSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-CHACHA20-POLY1305-SHA256", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA", "TLS-DHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-DHE-RSA-WITH-AES-256-CBC-SHA256", "TLS-DHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA", "TLS-DHE-DSS-WITH-AES-128-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-128-GCM-SHA256", "TLS-DHE-DSS-WITH-AES-256-CBC-SHA256", "TLS-DHE-DSS-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-RSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-AES-256-GCM-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-128-GCM-SHA256", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA", "TLS-ECDHE-ECDSA-WITH-AES-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-AES-128-CBC-SHA", "TLS-RSA-WITH-AES-256-CBC-SHA", "TLS-RSA-WITH-AES-128-CBC-SHA256", "TLS-RSA-WITH-AES-128-GCM-SHA256", "TLS-RSA-WITH-AES-256-CBC-SHA256", "TLS-RSA-WITH-AES-256-GCM-SHA384", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA", "TLS-DHE-RSA-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-DSS-WITH-CAMELLIA-256-CBC-SHA256", "TLS-DHE-RSA-WITH-SEED-CBC-SHA", "TLS-DHE-DSS-WITH-SEED-CBC-SHA", "TLS-DHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-DHE-DSS-WITH-ARIA-128-CBC-SHA256", "TLS-DHE-DSS-WITH-ARIA-256-CBC-SHA384", "TLS-RSA-WITH-SEED-CBC-SHA", "TLS-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-RSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-ECDSA-WITH-ARIA-128-CBC-SHA256", "TLS-ECDHE-ECDSA-WITH-ARIA-256-CBC-SHA384", "TLS-ECDHE-RSA-WITH-RC4-128-SHA", "TLS-ECDHE-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-DHE-DSS-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-3DES-EDE-CBC-SHA", "TLS-RSA-WITH-RC4-128-MD5", "TLS-RSA-WITH-RC4-128-SHA", "TLS-DHE-RSA-WITH-DES-CBC-SHA", "TLS-DHE-DSS-WITH-DES-CBC-SHA", "TLS-RSA-WITH-DES-CBC-SHA"]
    versions: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]


class Vip6MonitorItemObject(FortiObject[Vip6MonitorItem]):
    """Typed object for monitor table items with attribute access."""
    name: str


class Vip6QuicObject(FortiObject):
    """Nested object for quic field with attribute access."""
    max_idle_timeout: int
    max_udp_payload_size: int
    active_connection_id_limit: int
    ack_delay_exponent: int
    max_ack_delay: int
    max_datagram_frame_size: int
    active_migration: Literal["enable", "disable"]
    grease_quic_bit: Literal["enable", "disable"]


class Vip6Object(FortiObject):
    """Typed FortiObject for Vip6 with field access."""
    name: str
    id: int
    uuid: str
    comment: str
    type: Literal["static-nat", "server-load-balance", "access-proxy"]
    src_filter: FortiObjectList[Vip6SrcfilterItemObject]
    src_vip_filter: Literal["disable", "enable"]
    extip: str
    mappedip: str
    nat_source_vip: Literal["disable", "enable"]
    ndp_reply: Literal["disable", "enable"]
    portforward: Literal["disable", "enable"]
    protocol: Literal["tcp", "udp", "sctp"]
    extport: str
    mappedport: str
    color: int
    ldb_method: Literal["static", "round-robin", "weighted", "least-session", "least-rtt", "first-alive", "http-host"]
    server_type: Literal["http", "https", "imaps", "pop3s", "smtps", "ssl", "tcp", "udp", "ip"]
    http_redirect: Literal["enable", "disable"]
    persistence: Literal["none", "http-cookie", "ssl-session-id"]
    h2_support: Literal["enable", "disable"]
    h3_support: Literal["enable", "disable"]
    quic: Vip6QuicObject
    nat66: Literal["disable", "enable"]
    nat64: Literal["disable", "enable"]
    add_nat64_route: Literal["disable", "enable"]
    empty_cert_action: Literal["accept", "block", "accept-unmanageable"]
    user_agent_detect: Literal["disable", "enable"]
    client_cert: Literal["disable", "enable"]
    realservers: FortiObjectList[Vip6RealserversItemObject]
    http_cookie_domain_from_host: Literal["disable", "enable"]
    http_cookie_domain: str
    http_cookie_path: str
    http_cookie_generation: int
    http_cookie_age: int
    http_cookie_share: Literal["disable", "same-ip"]
    https_cookie_secure: Literal["disable", "enable"]
    http_multiplex: Literal["enable", "disable"]
    http_ip_header: Literal["enable", "disable"]
    http_ip_header_name: str
    outlook_web_access: Literal["disable", "enable"]
    weblogic_server: Literal["disable", "enable"]
    websphere_server: Literal["disable", "enable"]
    ssl_mode: Literal["half", "full"]
    ssl_certificate: FortiObjectList[Vip6SslcertificateItemObject]
    ssl_dh_bits: Literal["768", "1024", "1536", "2048", "3072", "4096"]
    ssl_algorithm: Literal["high", "medium", "low", "custom"]
    ssl_cipher_suites: FortiObjectList[Vip6SslciphersuitesItemObject]
    ssl_server_renegotiation: Literal["enable", "disable"]
    ssl_server_algorithm: Literal["high", "medium", "low", "custom", "client"]
    ssl_server_cipher_suites: FortiObjectList[Vip6SslserverciphersuitesItemObject]
    ssl_pfs: Literal["require", "deny", "allow"]
    ssl_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]
    ssl_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"]
    ssl_server_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"]
    ssl_server_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"]
    ssl_accept_ffdhe_groups: Literal["enable", "disable"]
    ssl_send_empty_frags: Literal["enable", "disable"]
    ssl_client_fallback: Literal["disable", "enable"]
    ssl_client_renegotiation: Literal["allow", "deny", "secure"]
    ssl_client_session_state_type: Literal["disable", "time", "count", "both"]
    ssl_client_session_state_timeout: int
    ssl_client_session_state_max: int
    ssl_client_rekey_count: int
    ssl_server_session_state_type: Literal["disable", "time", "count", "both"]
    ssl_server_session_state_timeout: int
    ssl_server_session_state_max: int
    ssl_http_location_conversion: Literal["enable", "disable"]
    ssl_http_match_host: Literal["enable", "disable"]
    ssl_hpkp: Literal["disable", "enable", "report-only"]
    ssl_hpkp_primary: str
    ssl_hpkp_backup: str
    ssl_hpkp_age: int
    ssl_hpkp_report_uri: str
    ssl_hpkp_include_subdomains: Literal["disable", "enable"]
    ssl_hsts: Literal["disable", "enable"]
    ssl_hsts_age: int
    ssl_hsts_include_subdomains: Literal["disable", "enable"]
    monitor: FortiObjectList[Vip6MonitorItemObject]
    max_embryonic_connections: int
    embedded_ipv4_address: Literal["disable", "enable"]
    ipv4_mappedip: str
    ipv4_mappedport: str


# ================================================================
# Main Endpoint Class
# ================================================================

class Vip6:
    """
    
    Endpoint: firewall/vip6
    Category: cmdb
    MKey: name
    """
    
    # Class attributes for introspection
    endpoint: ClassVar[str] = ...
    path: ClassVar[str] = ...
    category: ClassVar[str] = ...
    mkey: ClassVar[str] = ...
    capabilities: ClassVar[dict[str, Any]] = ...
    
    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...
    
    # ================================================================
    # GET Methods
    # ================================================================
    
    # CMDB with mkey - overloads for single vs list returns
    @overload
    def get(
        self,
        name: str,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> Vip6Object: ...
    
    @overload
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObjectList[Vip6Object]: ...
    
    def get_schema(
        self,
        vdom: str | None = ...,
        format: str = ...,
    ) -> FortiObject: ...

    # ================================================================
    # POST Method
    # ================================================================
    
    def post(
        self,
        payload_dict: Vip6Payload | None = ...,
        name: str | None = ...,
        id: int | None = ...,
        uuid: str | None = ...,
        comment: str | None = ...,
        type: Literal["static-nat", "server-load-balance", "access-proxy"] | None = ...,
        src_filter: str | list[str] | list[Vip6SrcfilterItem] | None = ...,
        src_vip_filter: Literal["disable", "enable"] | None = ...,
        extip: str | None = ...,
        mappedip: str | None = ...,
        nat_source_vip: Literal["disable", "enable"] | None = ...,
        ndp_reply: Literal["disable", "enable"] | None = ...,
        portforward: Literal["disable", "enable"] | None = ...,
        protocol: Literal["tcp", "udp", "sctp"] | None = ...,
        extport: str | None = ...,
        mappedport: str | None = ...,
        color: int | None = ...,
        ldb_method: Literal["static", "round-robin", "weighted", "least-session", "least-rtt", "first-alive", "http-host"] | None = ...,
        server_type: Literal["http", "https", "imaps", "pop3s", "smtps", "ssl", "tcp", "udp", "ip"] | None = ...,
        http_redirect: Literal["enable", "disable"] | None = ...,
        persistence: Literal["none", "http-cookie", "ssl-session-id"] | None = ...,
        h2_support: Literal["enable", "disable"] | None = ...,
        h3_support: Literal["enable", "disable"] | None = ...,
        quic: Vip6QuicDict | None = ...,
        nat66: Literal["disable", "enable"] | None = ...,
        nat64: Literal["disable", "enable"] | None = ...,
        add_nat64_route: Literal["disable", "enable"] | None = ...,
        empty_cert_action: Literal["accept", "block", "accept-unmanageable"] | None = ...,
        user_agent_detect: Literal["disable", "enable"] | None = ...,
        client_cert: Literal["disable", "enable"] | None = ...,
        realservers: str | list[str] | list[Vip6RealserversItem] | None = ...,
        http_cookie_domain_from_host: Literal["disable", "enable"] | None = ...,
        http_cookie_domain: str | None = ...,
        http_cookie_path: str | None = ...,
        http_cookie_generation: int | None = ...,
        http_cookie_age: int | None = ...,
        http_cookie_share: Literal["disable", "same-ip"] | None = ...,
        https_cookie_secure: Literal["disable", "enable"] | None = ...,
        http_multiplex: Literal["enable", "disable"] | None = ...,
        http_ip_header: Literal["enable", "disable"] | None = ...,
        http_ip_header_name: str | None = ...,
        outlook_web_access: Literal["disable", "enable"] | None = ...,
        weblogic_server: Literal["disable", "enable"] | None = ...,
        websphere_server: Literal["disable", "enable"] | None = ...,
        ssl_mode: Literal["half", "full"] | None = ...,
        ssl_certificate: str | list[str] | list[Vip6SslcertificateItem] | None = ...,
        ssl_dh_bits: Literal["768", "1024", "1536", "2048", "3072", "4096"] | None = ...,
        ssl_algorithm: Literal["high", "medium", "low", "custom"] | None = ...,
        ssl_cipher_suites: str | list[str] | list[Vip6SslciphersuitesItem] | None = ...,
        ssl_server_renegotiation: Literal["enable", "disable"] | None = ...,
        ssl_server_algorithm: Literal["high", "medium", "low", "custom", "client"] | None = ...,
        ssl_server_cipher_suites: str | list[str] | list[Vip6SslserverciphersuitesItem] | None = ...,
        ssl_pfs: Literal["require", "deny", "allow"] | None = ...,
        ssl_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"] | None = ...,
        ssl_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"] | None = ...,
        ssl_server_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"] | None = ...,
        ssl_server_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"] | None = ...,
        ssl_accept_ffdhe_groups: Literal["enable", "disable"] | None = ...,
        ssl_send_empty_frags: Literal["enable", "disable"] | None = ...,
        ssl_client_fallback: Literal["disable", "enable"] | None = ...,
        ssl_client_renegotiation: Literal["allow", "deny", "secure"] | None = ...,
        ssl_client_session_state_type: Literal["disable", "time", "count", "both"] | None = ...,
        ssl_client_session_state_timeout: int | None = ...,
        ssl_client_session_state_max: int | None = ...,
        ssl_client_rekey_count: int | None = ...,
        ssl_server_session_state_type: Literal["disable", "time", "count", "both"] | None = ...,
        ssl_server_session_state_timeout: int | None = ...,
        ssl_server_session_state_max: int | None = ...,
        ssl_http_location_conversion: Literal["enable", "disable"] | None = ...,
        ssl_http_match_host: Literal["enable", "disable"] | None = ...,
        ssl_hpkp: Literal["disable", "enable", "report-only"] | None = ...,
        ssl_hpkp_primary: str | None = ...,
        ssl_hpkp_backup: str | None = ...,
        ssl_hpkp_age: int | None = ...,
        ssl_hpkp_report_uri: str | None = ...,
        ssl_hpkp_include_subdomains: Literal["disable", "enable"] | None = ...,
        ssl_hsts: Literal["disable", "enable"] | None = ...,
        ssl_hsts_age: int | None = ...,
        ssl_hsts_include_subdomains: Literal["disable", "enable"] | None = ...,
        monitor: str | list[str] | list[Vip6MonitorItem] | None = ...,
        max_embryonic_connections: int | None = ...,
        embedded_ipv4_address: Literal["disable", "enable"] | None = ...,
        ipv4_mappedip: str | None = ...,
        ipv4_mappedport: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> Vip6Object: ...

    # ================================================================
    # PUT Method
    # ================================================================
    
    def put(
        self,
        payload_dict: Vip6Payload | None = ...,
        name: str | None = ...,
        id: int | None = ...,
        uuid: str | None = ...,
        comment: str | None = ...,
        type: Literal["static-nat", "server-load-balance", "access-proxy"] | None = ...,
        src_filter: str | list[str] | list[Vip6SrcfilterItem] | None = ...,
        src_vip_filter: Literal["disable", "enable"] | None = ...,
        extip: str | None = ...,
        mappedip: str | None = ...,
        nat_source_vip: Literal["disable", "enable"] | None = ...,
        ndp_reply: Literal["disable", "enable"] | None = ...,
        portforward: Literal["disable", "enable"] | None = ...,
        protocol: Literal["tcp", "udp", "sctp"] | None = ...,
        extport: str | None = ...,
        mappedport: str | None = ...,
        color: int | None = ...,
        ldb_method: Literal["static", "round-robin", "weighted", "least-session", "least-rtt", "first-alive", "http-host"] | None = ...,
        server_type: Literal["http", "https", "imaps", "pop3s", "smtps", "ssl", "tcp", "udp", "ip"] | None = ...,
        http_redirect: Literal["enable", "disable"] | None = ...,
        persistence: Literal["none", "http-cookie", "ssl-session-id"] | None = ...,
        h2_support: Literal["enable", "disable"] | None = ...,
        h3_support: Literal["enable", "disable"] | None = ...,
        quic: Vip6QuicDict | None = ...,
        nat66: Literal["disable", "enable"] | None = ...,
        nat64: Literal["disable", "enable"] | None = ...,
        add_nat64_route: Literal["disable", "enable"] | None = ...,
        empty_cert_action: Literal["accept", "block", "accept-unmanageable"] | None = ...,
        user_agent_detect: Literal["disable", "enable"] | None = ...,
        client_cert: Literal["disable", "enable"] | None = ...,
        realservers: str | list[str] | list[Vip6RealserversItem] | None = ...,
        http_cookie_domain_from_host: Literal["disable", "enable"] | None = ...,
        http_cookie_domain: str | None = ...,
        http_cookie_path: str | None = ...,
        http_cookie_generation: int | None = ...,
        http_cookie_age: int | None = ...,
        http_cookie_share: Literal["disable", "same-ip"] | None = ...,
        https_cookie_secure: Literal["disable", "enable"] | None = ...,
        http_multiplex: Literal["enable", "disable"] | None = ...,
        http_ip_header: Literal["enable", "disable"] | None = ...,
        http_ip_header_name: str | None = ...,
        outlook_web_access: Literal["disable", "enable"] | None = ...,
        weblogic_server: Literal["disable", "enable"] | None = ...,
        websphere_server: Literal["disable", "enable"] | None = ...,
        ssl_mode: Literal["half", "full"] | None = ...,
        ssl_certificate: str | list[str] | list[Vip6SslcertificateItem] | None = ...,
        ssl_dh_bits: Literal["768", "1024", "1536", "2048", "3072", "4096"] | None = ...,
        ssl_algorithm: Literal["high", "medium", "low", "custom"] | None = ...,
        ssl_cipher_suites: str | list[str] | list[Vip6SslciphersuitesItem] | None = ...,
        ssl_server_renegotiation: Literal["enable", "disable"] | None = ...,
        ssl_server_algorithm: Literal["high", "medium", "low", "custom", "client"] | None = ...,
        ssl_server_cipher_suites: str | list[str] | list[Vip6SslserverciphersuitesItem] | None = ...,
        ssl_pfs: Literal["require", "deny", "allow"] | None = ...,
        ssl_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"] | None = ...,
        ssl_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"] | None = ...,
        ssl_server_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"] | None = ...,
        ssl_server_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"] | None = ...,
        ssl_accept_ffdhe_groups: Literal["enable", "disable"] | None = ...,
        ssl_send_empty_frags: Literal["enable", "disable"] | None = ...,
        ssl_client_fallback: Literal["disable", "enable"] | None = ...,
        ssl_client_renegotiation: Literal["allow", "deny", "secure"] | None = ...,
        ssl_client_session_state_type: Literal["disable", "time", "count", "both"] | None = ...,
        ssl_client_session_state_timeout: int | None = ...,
        ssl_client_session_state_max: int | None = ...,
        ssl_client_rekey_count: int | None = ...,
        ssl_server_session_state_type: Literal["disable", "time", "count", "both"] | None = ...,
        ssl_server_session_state_timeout: int | None = ...,
        ssl_server_session_state_max: int | None = ...,
        ssl_http_location_conversion: Literal["enable", "disable"] | None = ...,
        ssl_http_match_host: Literal["enable", "disable"] | None = ...,
        ssl_hpkp: Literal["disable", "enable", "report-only"] | None = ...,
        ssl_hpkp_primary: str | None = ...,
        ssl_hpkp_backup: str | None = ...,
        ssl_hpkp_age: int | None = ...,
        ssl_hpkp_report_uri: str | None = ...,
        ssl_hpkp_include_subdomains: Literal["disable", "enable"] | None = ...,
        ssl_hsts: Literal["disable", "enable"] | None = ...,
        ssl_hsts_age: int | None = ...,
        ssl_hsts_include_subdomains: Literal["disable", "enable"] | None = ...,
        monitor: str | list[str] | list[Vip6MonitorItem] | None = ...,
        max_embryonic_connections: int | None = ...,
        embedded_ipv4_address: Literal["disable", "enable"] | None = ...,
        ipv4_mappedip: str | None = ...,
        ipv4_mappedport: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> Vip6Object: ...

    # ================================================================
    # DELETE Method
    # ================================================================
    
    def delete(
        self,
        name: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObject[Any]: ...

    # ================================================================
    # Utility Methods
    # ================================================================
    
    def exists(
        self,
        name: str,
        vdom: str | bool | None = ...,
    ) -> bool: ...
    
    def set(
        self,
        payload_dict: Vip6Payload | None = ...,
        name: str | None = ...,
        id: int | None = ...,
        uuid: str | None = ...,
        comment: str | None = ...,
        type: Literal["static-nat", "server-load-balance", "access-proxy"] | None = ...,
        src_filter: str | list[str] | list[Vip6SrcfilterItem] | None = ...,
        src_vip_filter: Literal["disable", "enable"] | None = ...,
        extip: str | None = ...,
        mappedip: str | None = ...,
        nat_source_vip: Literal["disable", "enable"] | None = ...,
        ndp_reply: Literal["disable", "enable"] | None = ...,
        portforward: Literal["disable", "enable"] | None = ...,
        protocol: Literal["tcp", "udp", "sctp"] | None = ...,
        extport: str | None = ...,
        mappedport: str | None = ...,
        color: int | None = ...,
        ldb_method: Literal["static", "round-robin", "weighted", "least-session", "least-rtt", "first-alive", "http-host"] | None = ...,
        server_type: Literal["http", "https", "imaps", "pop3s", "smtps", "ssl", "tcp", "udp", "ip"] | None = ...,
        http_redirect: Literal["enable", "disable"] | None = ...,
        persistence: Literal["none", "http-cookie", "ssl-session-id"] | None = ...,
        h2_support: Literal["enable", "disable"] | None = ...,
        h3_support: Literal["enable", "disable"] | None = ...,
        quic: Vip6QuicDict | None = ...,
        nat66: Literal["disable", "enable"] | None = ...,
        nat64: Literal["disable", "enable"] | None = ...,
        add_nat64_route: Literal["disable", "enable"] | None = ...,
        empty_cert_action: Literal["accept", "block", "accept-unmanageable"] | None = ...,
        user_agent_detect: Literal["disable", "enable"] | None = ...,
        client_cert: Literal["disable", "enable"] | None = ...,
        realservers: str | list[str] | list[Vip6RealserversItem] | None = ...,
        http_cookie_domain_from_host: Literal["disable", "enable"] | None = ...,
        http_cookie_domain: str | None = ...,
        http_cookie_path: str | None = ...,
        http_cookie_generation: int | None = ...,
        http_cookie_age: int | None = ...,
        http_cookie_share: Literal["disable", "same-ip"] | None = ...,
        https_cookie_secure: Literal["disable", "enable"] | None = ...,
        http_multiplex: Literal["enable", "disable"] | None = ...,
        http_ip_header: Literal["enable", "disable"] | None = ...,
        http_ip_header_name: str | None = ...,
        outlook_web_access: Literal["disable", "enable"] | None = ...,
        weblogic_server: Literal["disable", "enable"] | None = ...,
        websphere_server: Literal["disable", "enable"] | None = ...,
        ssl_mode: Literal["half", "full"] | None = ...,
        ssl_certificate: str | list[str] | list[Vip6SslcertificateItem] | None = ...,
        ssl_dh_bits: Literal["768", "1024", "1536", "2048", "3072", "4096"] | None = ...,
        ssl_algorithm: Literal["high", "medium", "low", "custom"] | None = ...,
        ssl_cipher_suites: str | list[str] | list[Vip6SslciphersuitesItem] | None = ...,
        ssl_server_renegotiation: Literal["enable", "disable"] | None = ...,
        ssl_server_algorithm: Literal["high", "medium", "low", "custom", "client"] | None = ...,
        ssl_server_cipher_suites: str | list[str] | list[Vip6SslserverciphersuitesItem] | None = ...,
        ssl_pfs: Literal["require", "deny", "allow"] | None = ...,
        ssl_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"] | None = ...,
        ssl_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3"] | None = ...,
        ssl_server_min_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"] | None = ...,
        ssl_server_max_version: Literal["ssl-3.0", "tls-1.0", "tls-1.1", "tls-1.2", "tls-1.3", "client"] | None = ...,
        ssl_accept_ffdhe_groups: Literal["enable", "disable"] | None = ...,
        ssl_send_empty_frags: Literal["enable", "disable"] | None = ...,
        ssl_client_fallback: Literal["disable", "enable"] | None = ...,
        ssl_client_renegotiation: Literal["allow", "deny", "secure"] | None = ...,
        ssl_client_session_state_type: Literal["disable", "time", "count", "both"] | None = ...,
        ssl_client_session_state_timeout: int | None = ...,
        ssl_client_session_state_max: int | None = ...,
        ssl_client_rekey_count: int | None = ...,
        ssl_server_session_state_type: Literal["disable", "time", "count", "both"] | None = ...,
        ssl_server_session_state_timeout: int | None = ...,
        ssl_server_session_state_max: int | None = ...,
        ssl_http_location_conversion: Literal["enable", "disable"] | None = ...,
        ssl_http_match_host: Literal["enable", "disable"] | None = ...,
        ssl_hpkp: Literal["disable", "enable", "report-only"] | None = ...,
        ssl_hpkp_primary: str | None = ...,
        ssl_hpkp_backup: str | None = ...,
        ssl_hpkp_age: int | None = ...,
        ssl_hpkp_report_uri: str | None = ...,
        ssl_hpkp_include_subdomains: Literal["disable", "enable"] | None = ...,
        ssl_hsts: Literal["disable", "enable"] | None = ...,
        ssl_hsts_age: int | None = ...,
        ssl_hsts_include_subdomains: Literal["disable", "enable"] | None = ...,
        monitor: str | list[str] | list[Vip6MonitorItem] | None = ...,
        max_embryonic_connections: int | None = ...,
        embedded_ipv4_address: Literal["disable", "enable"] | None = ...,
        ipv4_mappedip: str | None = ...,
        ipv4_mappedport: str | None = ...,
        vdom: str | bool | None = ...,
        error_mode: Literal["raise", "return", "print"] | None = ...,
        error_format: Literal["detailed", "simple", "code_only"] | None = ...,
    ) -> FortiObject[Any]: ...
    
    # Helper methods
    @staticmethod
    def help(field_name: str | None = ...) -> str: ...
    
    @staticmethod
    def fields(detailed: bool = ...) -> list[str] | list[dict[str, Any]]: ...
    
    @staticmethod
    def field_info(field_name: str) -> FortiObject[Any]: ...
    
    @staticmethod
    def validate_field(name: str, value: Any) -> bool: ...
    
    @staticmethod
    def required_fields() -> list[str]: ...
    
    @staticmethod
    def defaults() -> FortiObject[Any]: ...
    
    @staticmethod
    def schema() -> FortiObject[Any]: ...


__all__ = [
    "Vip6",
    "Vip6Payload",
    "Vip6Response",
    "Vip6Object",
]


"""Validation helpers for router/rip - Auto-generated"""

from typing import Any, TypedDict, Literal
from typing_extensions import NotRequired

# Import common validators from central _helpers module
from hfortix_fortios._helpers import (
    validate_enable_disable,
    validate_integer_range,
    validate_string_length,
    validate_port_number,
    validate_ip_address,
    validate_ipv6_address,
    validate_mac_address,
)

# Import central validation functions (avoid duplication across 1,062 files)
from hfortix_fortios._helpers.validation import (
    validate_required_fields as _validate_required_fields,
    validate_enum_field as _validate_enum_field,
    validate_query_parameter as _validate_query_parameter,
)

# ============================================================================
# Required Fields Validation
# Auto-generated from schema
# ============================================================================

# ⚠️  IMPORTANT: FortiOS schemas have known issues with required field marking:

# Do NOT use this list for strict validation - test with the actual FortiOS API!

# Fields marked as required (after filtering false positives)
REQUIRED_FIELDS = [
]

# Fields with defaults (optional)
FIELDS_WITH_DEFAULTS = {
    "default-information-originate": "disable",
    "default-metric": 1,
    "max-out-metric": 0,
    "update-timer": 30,
    "timeout-timer": 180,
    "garbage-timer": 120,
    "version": "2",
}

# ============================================================================
# Deprecated Fields
# Auto-generated from schema - warns users about deprecated fields
# ============================================================================

# Deprecated fields with migration guidance
DEPRECATED_FIELDS = {
}

# ============================================================================
# Field Metadata (Type Information & Descriptions)
# Auto-generated from schema - use for IDE autocomplete and documentation
# ============================================================================

# Field types mapping
FIELD_TYPES = {
    "default-information-originate": "option",  # Enable/disable generation of default route.
    "default-metric": "integer",  # Default metric.
    "max-out-metric": "integer",  # Maximum metric allowed to output(0 means 'not set').
    "distance": "string",  # Distance.
    "distribute-list": "string",  # Distribute list.
    "neighbor": "string",  # Neighbor.
    "network": "string",  # Network.
    "offset-list": "string",  # Offset list.
    "passive-interface": "string",  # Passive interface configuration.
    "redistribute": "string",  # Redistribute configuration.
    "update-timer": "integer",  # Update timer in seconds.
    "timeout-timer": "integer",  # Timeout timer in seconds.
    "garbage-timer": "integer",  # Garbage timer in seconds.
    "version": "option",  # RIP version.
    "interface": "string",  # RIP interface configuration.
}

# Field descriptions (help text from FortiOS API)
FIELD_DESCRIPTIONS = {
    "default-information-originate": "Enable/disable generation of default route.",
    "default-metric": "Default metric.",
    "max-out-metric": "Maximum metric allowed to output(0 means 'not set').",
    "distance": "Distance.",
    "distribute-list": "Distribute list.",
    "neighbor": "Neighbor.",
    "network": "Network.",
    "offset-list": "Offset list.",
    "passive-interface": "Passive interface configuration.",
    "redistribute": "Redistribute configuration.",
    "update-timer": "Update timer in seconds.",
    "timeout-timer": "Timeout timer in seconds.",
    "garbage-timer": "Garbage timer in seconds.",
    "version": "RIP version.",
    "interface": "RIP interface configuration.",
}

# Field constraints (string lengths, integer ranges)
FIELD_CONSTRAINTS = {
    "default-metric": {"type": "integer", "min": 1, "max": 16},
    "max-out-metric": {"type": "integer", "min": 0, "max": 15},
    "update-timer": {"type": "integer", "min": 1, "max": 2147483647},
    "timeout-timer": {"type": "integer", "min": 5, "max": 2147483647},
    "garbage-timer": {"type": "integer", "min": 5, "max": 2147483647},
}

# Nested schemas (for table/list fields with children)
NESTED_SCHEMAS = {
    "distance": {
        "id": {
            "type": "integer",
            "help": "Distance ID.",
            "required": True,
            "default": 0,
            "min_value": 0,
            "max_value": 4294967295,
        },
        "prefix": {
            "type": "ipv4-classnet-any",
            "help": "Distance prefix.",
            "default": "0.0.0.0 0.0.0.0",
        },
        "distance": {
            "type": "integer",
            "help": "Distance (1 - 255).",
            "required": True,
            "default": 0,
            "min_value": 1,
            "max_value": 255,
        },
        "access-list": {
            "type": "string",
            "help": "Access list for route destination.",
            "default": "",
            "max_length": 35,
        },
    },
    "distribute-list": {
        "id": {
            "type": "integer",
            "help": "Distribute list ID.",
            "required": True,
            "default": 0,
            "min_value": 0,
            "max_value": 4294967295,
        },
        "status": {
            "type": "option",
            "help": "Status.",
            "default": "disable",
            "options": ["enable", "disable"],
        },
        "direction": {
            "type": "option",
            "help": "Distribute list direction.",
            "required": True,
            "default": "out",
            "options": ["in", "out"],
        },
        "listname": {
            "type": "string",
            "help": "Distribute access/prefix list name.",
            "required": True,
            "default": "",
            "max_length": 35,
        },
        "interface": {
            "type": "string",
            "help": "Distribute list interface name.",
            "default": "",
            "max_length": 15,
        },
    },
    "neighbor": {
        "id": {
            "type": "integer",
            "help": "Neighbor entry ID.",
            "default": 0,
            "min_value": 0,
            "max_value": 4294967295,
        },
        "ip": {
            "type": "ipv4-address",
            "help": "IP address.",
            "required": True,
            "default": "0.0.0.0",
        },
    },
    "network": {
        "id": {
            "type": "integer",
            "help": "Network entry ID.",
            "default": 0,
            "min_value": 0,
            "max_value": 4294967295,
        },
        "prefix": {
            "type": "ipv4-classnet",
            "help": "Network prefix.",
            "default": "0.0.0.0 0.0.0.0",
        },
    },
    "offset-list": {
        "id": {
            "type": "integer",
            "help": "Offset-list ID.",
            "required": True,
            "default": 0,
            "min_value": 0,
            "max_value": 4294967295,
        },
        "status": {
            "type": "option",
            "help": "Status.",
            "default": "enable",
            "options": ["enable", "disable"],
        },
        "direction": {
            "type": "option",
            "help": "Offset list direction.",
            "required": True,
            "default": "out",
            "options": ["in", "out"],
        },
        "access-list": {
            "type": "string",
            "help": "Access list name.",
            "required": True,
            "default": "",
            "max_length": 35,
        },
        "offset": {
            "type": "integer",
            "help": "Offset.",
            "required": True,
            "default": 0,
            "min_value": 1,
            "max_value": 16,
        },
        "interface": {
            "type": "string",
            "help": "Interface name.",
            "default": "",
            "max_length": 15,
        },
    },
    "passive-interface": {
        "name": {
            "type": "string",
            "help": "Passive interface name.",
            "required": True,
            "default": "",
            "max_length": 79,
        },
    },
    "redistribute": {
        "name": {
            "type": "string",
            "help": "Redistribute name.",
            "required": True,
            "default": "",
            "max_length": 35,
        },
        "status": {
            "type": "option",
            "help": "Status.",
            "default": "disable",
            "options": ["enable", "disable"],
        },
        "metric": {
            "type": "integer",
            "help": "Redistribute metric setting.",
            "default": 0,
            "min_value": 1,
            "max_value": 16,
        },
        "routemap": {
            "type": "string",
            "help": "Route map name.",
            "default": "",
            "max_length": 35,
        },
    },
    "interface": {
        "name": {
            "type": "string",
            "help": "Interface name.",
            "default": "",
            "max_length": 35,
        },
        "auth-keychain": {
            "type": "string",
            "help": "Authentication key-chain name.",
            "default": "",
            "max_length": 35,
        },
        "auth-mode": {
            "type": "option",
            "help": "Authentication mode.",
            "default": "none",
            "options": ["none", "text", "md5"],
        },
        "auth-string": {
            "type": "password",
            "help": "Authentication string/password.",
            "max_length": 16,
        },
        "receive-version": {
            "type": "option",
            "help": "Receive version.",
            "default": "",
            "options": ["1", "2"],
        },
        "send-version": {
            "type": "option",
            "help": "Send version.",
            "default": "",
            "options": ["1", "2"],
        },
        "send-version2-broadcast": {
            "type": "option",
            "help": "Enable/disable broadcast version 1 compatible packets.",
            "default": "disable",
            "options": ["disable", "enable"],
        },
        "split-horizon-status": {
            "type": "option",
            "help": "Enable/disable split horizon.",
            "default": "enable",
            "options": ["enable", "disable"],
        },
        "split-horizon": {
            "type": "option",
            "help": "Enable/disable split horizon.",
            "default": "poisoned",
            "options": ["poisoned", "regular"],
        },
        "flags": {
            "type": "integer",
            "help": "Flags.",
            "default": 8,
            "min_value": 0,
            "max_value": 255,
        },
    },
}


# Valid enum values from API documentation
VALID_BODY_DEFAULT_INFORMATION_ORIGINATE = [
    "enable",
    "disable",
]
VALID_BODY_VERSION = [
    "1",
    "2",
]
VALID_QUERY_ACTION = ["default", "schema"]

# ============================================================================
# GET Validation
# ============================================================================


def validate_router_rip_get(
    attr: str | None = None,
    filters: dict[str, Any] | None = None,
    **params: Any,
) -> tuple[bool, str | None]:
    """Validate GET request parameters for router/rip."""
    # Validate query parameters using central function
    if "action" in params:
        is_valid, error = _validate_query_parameter(
            "action",
            params.get("action"),
            VALID_QUERY_ACTION
        )
        if not is_valid:
            return (False, error)

    return (True, None)


# ============================================================================
# POST Validation
# ============================================================================


def validate_router_rip_post(
    payload: dict,
    **params: Any,
) -> tuple[bool, str | None]:
    """Validate POST request to create new router/rip object."""
    # Step 1: Validate required fields using central function
    is_valid, error = _validate_required_fields(
        payload,
        REQUIRED_FIELDS,
        FIELD_DESCRIPTIONS
    )
    if not is_valid:
        return (False, error)

    # Step 2: Validate enum values using central function
    if "default-information-originate" in payload:
        is_valid, error = _validate_enum_field(
            "default-information-originate",
            payload["default-information-originate"],
            VALID_BODY_DEFAULT_INFORMATION_ORIGINATE,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "version" in payload:
        is_valid, error = _validate_enum_field(
            "version",
            payload["version"],
            VALID_BODY_VERSION,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)

    return (True, None)


# ============================================================================
# PUT Validation
# ============================================================================


def validate_router_rip_put(
    payload: dict,
    **params: Any,
) -> tuple[bool, str | None]:
    """Validate PUT request to update router/rip."""
    # Validate enum values using central function
    if "default-information-originate" in payload:
        is_valid, error = _validate_enum_field(
            "default-information-originate",
            payload["default-information-originate"],
            VALID_BODY_DEFAULT_INFORMATION_ORIGINATE,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)
    if "version" in payload:
        is_valid, error = _validate_enum_field(
            "version",
            payload["version"],
            VALID_BODY_VERSION,
            FIELD_DESCRIPTIONS
        )
        if not is_valid:
            return (False, error)

    return (True, None)


# ============================================================================
# Metadata Access Functions
# Imported from central module to avoid duplication across 1,062 files
# Bound to this endpoint's data using functools.partial (saves ~7KB per file)
# ============================================================================

from functools import partial
from hfortix_fortios._helpers.metadata import (
    get_field_description,
    get_field_type,
    get_field_constraints,
    get_field_default,
    get_field_options,
    get_nested_schema,
    get_all_fields,
    get_field_metadata,
    validate_field_value,
)

# Bind module-specific data to central functions using partial application
get_field_description = partial(get_field_description, FIELD_DESCRIPTIONS)
get_field_type = partial(get_field_type, FIELD_TYPES)
get_field_constraints = partial(get_field_constraints, FIELD_CONSTRAINTS)
get_field_default = partial(get_field_default, FIELDS_WITH_DEFAULTS)
get_field_options = partial(get_field_options, globals())
get_nested_schema = partial(get_nested_schema, NESTED_SCHEMAS)
get_all_fields = partial(get_all_fields, FIELD_TYPES)
get_field_metadata = partial(get_field_metadata, FIELD_TYPES, FIELD_DESCRIPTIONS, 
                             FIELD_CONSTRAINTS, FIELDS_WITH_DEFAULTS, REQUIRED_FIELDS,
                             NESTED_SCHEMAS, globals())
validate_field_value = partial(validate_field_value, FIELD_TYPES, FIELD_DESCRIPTIONS,
                               FIELD_CONSTRAINTS, globals())


# ============================================================================
# Schema Information
# Metadata about this endpoint schema
# ============================================================================

SCHEMA_INFO = {
    "endpoint": "router/rip",
    "category": "cmdb",
    "api_path": "router/rip",
    "help": "Configure RIP.",
    "total_fields": 15,
    "required_fields_count": 0,
    "fields_with_defaults_count": 7,
}


def get_schema_info() -> dict[str, Any]:
    """Get information about this endpoint schema."""
    return SCHEMA_INFO.copy()



"""FortiOS CMDB - Gtp category (stub)"""

from typing import Any
from ..gtp_base import Gtp as GtpBase
from .flush import Flush

class Gtp(GtpBase):
    """Gtp endpoints wrapper for CMDB API."""

    flush: Flush

    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...



"""
Pydantic Models for CMDB - system/snmp/community

Runtime validation models for system/snmp/community configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional
from enum import Enum

# ============================================================================
# Enum Definitions for Child Table Fields (for fields with 4+ allowed values)
# ============================================================================

# ============================================================================
# Child Table Models (sorted deepest-first so nested models are defined before their parents)
# ============================================================================

class CommunityVdoms(BaseModel):
    """
    Child table model for vdoms.
    
    SNMP access control VDOMs.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=79, description="VDOM name.")  # datasource: ['system.vdom.name']
class CommunityHosts6(BaseModel):
    """
    Child table model for hosts6.
    
    Configure IPv6 SNMP managers.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    id_: int = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="Host6 entry ID.")    
    source_ipv6: str | None = Field(default="::", description="Source IPv6 address for SNMP traps.")    
    ipv6: str = Field(default="::/0", description="SNMP manager IPv6 address prefix.")    
    ha_direct: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable direct management of HA cluster members.")    
    host_type: Literal["any", "query", "trap"] | None = Field(default="any", description="Control whether the SNMP manager sends SNMP queries, receives SNMP traps, or both.")    
    interface_select_method: Literal["auto", "sdwan", "specify"] | None = Field(default="auto", description="Specify how to select outgoing interface to reach server.")    
    interface: str = Field(max_length=15, description="Specify outgoing interface to reach server.")  # datasource: ['system.interface.name']    
    vrf_select: int | None = Field(ge=0, le=511, default=0, description="VRF ID used for connection to server.")
class CommunityHosts(BaseModel):
    """
    Child table model for hosts.
    
    Configure IPv4 SNMP managers (hosts).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    id_: int = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="Host entry ID.")    
    source_ip: str | None = Field(default="0.0.0.0", description="Source IPv4 address for SNMP traps.")    
    ip: str = Field(description="IPv4 address of the SNMP manager (host).")    
    ha_direct: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable direct management of HA cluster members.")    
    host_type: Literal["any", "query", "trap"] | None = Field(default="any", description="Control whether the SNMP manager sends SNMP queries, receives SNMP traps, or both. No traps will be sent when IP type is subnet.")    
    interface_select_method: Literal["auto", "sdwan", "specify"] | None = Field(default="auto", description="Specify how to select outgoing interface to reach server.")    
    interface: str = Field(max_length=15, description="Specify outgoing interface to reach server.")  # datasource: ['system.interface.name']    
    vrf_select: int | None = Field(ge=0, le=511, default=0, description="VRF ID used for connection to server.")
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class CommunityEventsEnum(str, Enum):
    """Allowed values for events field."""
    CPU_HIGH = "cpu-high"
    MEM_LOW = "mem-low"
    LOG_FULL = "log-full"
    INTF_IP = "intf-ip"
    VPN_TUN_UP = "vpn-tun-up"
    VPN_TUN_DOWN = "vpn-tun-down"
    HA_SWITCH = "ha-switch"
    HA_HB_FAILURE = "ha-hb-failure"
    IPS_SIGNATURE = "ips-signature"
    IPS_ANOMALY = "ips-anomaly"
    AV_VIRUS = "av-virus"
    AV_OVERSIZE = "av-oversize"
    AV_PATTERN = "av-pattern"
    AV_FRAGMENTED = "av-fragmented"
    FM_IF_CHANGE = "fm-if-change"
    FM_CONF_CHANGE = "fm-conf-change"
    BGP_ESTABLISHED = "bgp-established"
    BGP_BACKWARD_TRANSITION = "bgp-backward-transition"
    HA_MEMBER_UP = "ha-member-up"
    HA_MEMBER_DOWN = "ha-member-down"
    ENT_CONF_CHANGE = "ent-conf-change"
    AV_CONSERVE = "av-conserve"
    AV_BYPASS = "av-bypass"
    AV_OVERSIZE_PASSED = "av-oversize-passed"
    AV_OVERSIZE_BLOCKED = "av-oversize-blocked"
    IPS_PKG_UPDATE = "ips-pkg-update"
    IPS_FAIL_OPEN = "ips-fail-open"
    FAZ_DISCONNECT = "faz-disconnect"
    FAZ = "faz"
    WC_AP_UP = "wc-ap-up"
    WC_AP_DOWN = "wc-ap-down"
    FSWCTL_SESSION_UP = "fswctl-session-up"
    FSWCTL_SESSION_DOWN = "fswctl-session-down"
    LOAD_BALANCE_REAL_SERVER_DOWN = "load-balance-real-server-down"
    DEVICE_NEW = "device-new"
    PER_CPU_HIGH = "per-cpu-high"
    DHCP = "dhcp"
    POOL_USAGE = "pool-usage"
    IPPOOL = "ippool"
    INTERFACE = "interface"
    OSPF_NBR_STATE_CHANGE = "ospf-nbr-state-change"
    OSPF_VIRTNBR_STATE_CHANGE = "ospf-virtnbr-state-change"
    BFD = "bfd"


# ============================================================================
# Main Model
# ============================================================================

class CommunityModel(BaseModel):
    """
    Pydantic model for system/snmp/community configuration.
    
    SNMP community configuration.
    
    Validation Rules:        - id_: min=0 max=4294967295 pattern=        - name: max_length=35 pattern=        - status: pattern=        - hosts: pattern=        - hosts6: pattern=        - query_v1_status: pattern=        - query_v1_port: min=1 max=65535 pattern=        - query_v2c_status: pattern=        - query_v2c_port: min=0 max=65535 pattern=        - trap_v1_status: pattern=        - trap_v1_lport: min=1 max=65535 pattern=        - trap_v1_rport: min=1 max=65535 pattern=        - trap_v2c_status: pattern=        - trap_v2c_lport: min=1 max=65535 pattern=        - trap_v2c_rport: min=1 max=65535 pattern=        - events: pattern=        - mib_view: max_length=32 pattern=        - vdoms: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    id_: int = Field(ge=0, le=4294967295, default=0, serialization_alias="id", description="Community ID.")    
    name: str = Field(max_length=35, description="Community name.")    
    status: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable this SNMP community.")    
    hosts: list[CommunityHosts] = Field(default_factory=list, description="Configure IPv4 SNMP managers (hosts).")    
    hosts6: list[CommunityHosts6] = Field(default_factory=list, description="Configure IPv6 SNMP managers.")    
    query_v1_status: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable SNMP v1 queries.")    
    query_v1_port: int | None = Field(ge=1, le=65535, default=161, description="SNMP v1 query port (default = 161).")    
    query_v2c_status: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable SNMP v2c queries.")    
    query_v2c_port: int | None = Field(ge=0, le=65535, default=161, description="SNMP v2c query port (default = 161).")    
    trap_v1_status: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable SNMP v1 traps.")    
    trap_v1_lport: int | None = Field(ge=1, le=65535, default=162, description="SNMP v1 trap local port (default = 162).")    
    trap_v1_rport: int | None = Field(ge=1, le=65535, default=162, description="SNMP v1 trap remote port (default = 162).")    
    trap_v2c_status: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable SNMP v2c traps.")    
    trap_v2c_lport: int | None = Field(ge=1, le=65535, default=162, description="SNMP v2c trap local port (default = 162).")    
    trap_v2c_rport: int | None = Field(ge=1, le=65535, default=162, description="SNMP v2c trap remote port (default = 162).")    
    events: list[CommunityEventsEnum] = Field(default_factory=list, description="SNMP trap events.")    
    mib_view: str | None = Field(max_length=32, default=None, description="SNMP access control MIB view.")  # datasource: ['system.snmp.mib-view.name']    
    vdoms: list[CommunityVdoms] = Field(default_factory=list, description="SNMP access control VDOMs.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    @field_validator('mib_view')
    @classmethod
    def validate_mib_view(cls, v: Any) -> Any:
        """
        Validate mib_view field.
        
        Datasource: ['system.snmp.mib-view.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "CommunityModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)
    # ========================================================================
    # Datasource Validation Methods
    # ========================================================================    
    async def validate_hosts_references(self, client: Any) -> list[str]:
        """
        Validate hosts references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - system/interface        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = CommunityModel(
            ...     hosts=[{"interface": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_hosts_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.system.snmp.community.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "hosts", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("interface")
            else:
                value = getattr(item, "interface", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.system.interface.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Hosts '{value}' not found in "
                    "system/interface"
                )        
        return errors    
    async def validate_hosts6_references(self, client: Any) -> list[str]:
        """
        Validate hosts6 references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - system/interface        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = CommunityModel(
            ...     hosts6=[{"interface": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_hosts6_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.system.snmp.community.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "hosts6", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("interface")
            else:
                value = getattr(item, "interface", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.system.interface.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Hosts6 '{value}' not found in "
                    "system/interface"
                )        
        return errors    
    async def validate_mib_view_references(self, client: Any) -> list[str]:
        """
        Validate mib_view references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - system/snmp/mib-view        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = CommunityModel(
            ...     mib_view="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_mib_view_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.system.snmp.community.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "mib_view", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.system.snmp.mib_view.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Mib-View '{value}' not found in "
                "system/snmp/mib-view"
            )        
        return errors    
    async def validate_vdoms_references(self, client: Any) -> list[str]:
        """
        Validate vdoms references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - system/vdom        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = CommunityModel(
            ...     vdoms=[{"name": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_vdoms_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.system.snmp.community.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "vdoms", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("name")
            else:
                value = getattr(item, "name", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.system.vdom.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Vdoms '{value}' not found in "
                    "system/vdom"
                )        
        return errors    
    async def validate_all_references(self, client: Any) -> list[str]:
        """
        Validate ALL datasource references in this model.
        
        Convenience method that runs all validate_*_references() methods
        and aggregates the results.
        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of all validation errors found
            
        Example:
            >>> errors = await policy.validate_all_references(fgt._client)
            >>> if errors:
            ...     for error in errors:
            ...         print(f"  - {error}")
        """
        all_errors = []
        
        errors = await self.validate_hosts_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_hosts6_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_mib_view_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_vdoms_references(client)
        all_errors.extend(errors)        
        return all_errors

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "CommunityModel",    "CommunityHosts",    "CommunityHosts6",    "CommunityVdoms",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:24:01.511116Z
# ============================================================================


"""FortiOS CMDB - BlacklistedCertificates category (stub)"""

from typing import Any
from ..blacklisted_certificates_base import BlacklistedCertificates as BlacklistedCertificatesBase
from .statistics import Statistics

class BlacklistedCertificates(BlacklistedCertificatesBase):
    """BlacklistedCertificates endpoints wrapper for CMDB API."""

    statistics: Statistics

    def __init__(self, client: Any) -> None:
        """Initialize endpoint with HTTP client."""
        ...



"""
Pydantic Models for CMDB - wireless_controller/hotspot20/hs_profile

Runtime validation models for wireless_controller/hotspot20/hs_profile configuration.
Generated from FortiOS schema version unknown.
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional
from enum import Enum

# ============================================================================
# Enum Definitions for Child Table Fields (for fields with 4+ allowed values)
# ============================================================================

# ============================================================================
# Child Table Models (sorted deepest-first so nested models are defined before their parents)
# ============================================================================

class HsProfileOsuProvider(BaseModel):
    """
    Child table model for osu-provider.
    
    Manually selected list of OSU provider(s).
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        use_enum_values = True  # Use enum values instead of names
    
    name: str = Field(max_length=35, description="OSU provider name.")  # datasource: ['wireless-controller.hotspot20.h2qp-osu-provider.name']
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class HsProfileAccessNetworkTypeEnum(str, Enum):
    """Allowed values for access_network_type field."""
    PRIVATE_NETWORK = "private-network"
    PRIVATE_NETWORK_WITH_GUEST_ACCESS = "private-network-with-guest-access"
    CHARGEABLE_PUBLIC_NETWORK = "chargeable-public-network"
    FREE_PUBLIC_NETWORK = "free-public-network"
    PERSONAL_DEVICE_NETWORK = "personal-device-network"
    EMERGENCY_SERVICES_ONLY_NETWORK = "emergency-services-only-network"
    TEST_OR_EXPERIMENTAL = "test-or-experimental"
    WILDCARD = "wildcard"

class HsProfileVenueGroupEnum(str, Enum):
    """Allowed values for venue_group field."""
    UNSPECIFIED = "unspecified"
    ASSEMBLY = "assembly"
    BUSINESS = "business"
    EDUCATIONAL = "educational"
    FACTORY = "factory"
    INSTITUTIONAL = "institutional"
    MERCANTILE = "mercantile"
    RESIDENTIAL = "residential"
    STORAGE = "storage"
    UTILITY = "utility"
    VEHICULAR = "vehicular"
    OUTDOOR = "outdoor"

class HsProfileVenueTypeEnum(str, Enum):
    """Allowed values for venue_type field."""
    UNSPECIFIED = "unspecified"
    ARENA = "arena"
    STADIUM = "stadium"
    PASSENGER_TERMINAL = "passenger-terminal"
    AMPHITHEATER = "amphitheater"
    AMUSEMENT_PARK = "amusement-park"
    PLACE_OF_WORSHIP = "place-of-worship"
    CONVENTION_CENTER = "convention-center"
    LIBRARY = "library"
    MUSEUM = "museum"
    RESTAURANT = "restaurant"
    THEATER = "theater"
    BAR = "bar"
    COFFEE_SHOP = "coffee-shop"
    ZOO_OR_AQUARIUM = "zoo-or-aquarium"
    EMERGENCY_CENTER = "emergency-center"
    DOCTOR_OFFICE = "doctor-office"
    BANK = "bank"
    FIRE_STATION = "fire-station"
    POLICE_STATION = "police-station"
    POST_OFFICE = "post-office"
    PROFESSIONAL_OFFICE = "professional-office"
    RESEARCH_FACILITY = "research-facility"
    ATTORNEY_OFFICE = "attorney-office"
    PRIMARY_SCHOOL = "primary-school"
    SECONDARY_SCHOOL = "secondary-school"
    UNIVERSITY_OR_COLLEGE = "university-or-college"
    FACTORY = "factory"
    HOSPITAL = "hospital"
    LONG_TERM_CARE_FACILITY = "long-term-care-facility"
    REHAB_CENTER = "rehab-center"
    GROUP_HOME = "group-home"
    PRISON_OR_JAIL = "prison-or-jail"
    RETAIL_STORE = "retail-store"
    GROCERY_MARKET = "grocery-market"
    AUTO_SERVICE_STATION = "auto-service-station"
    SHOPPING_MALL = "shopping-mall"
    GAS_STATION = "gas-station"
    PRIVATE = "private"
    HOTEL_OR_MOTEL = "hotel-or-motel"
    DORMITORY = "dormitory"
    BOARDING_HOUSE = "boarding-house"
    AUTOMOBILE = "automobile"
    AIRPLANE = "airplane"
    BUS = "bus"
    FERRY = "ferry"
    SHIP_OR_BOAT = "ship-or-boat"
    TRAIN = "train"
    MOTOR_BIKE = "motor-bike"
    MUNI_MESH_NETWORK = "muni-mesh-network"
    CITY_PARK = "city-park"
    REST_AREA = "rest-area"
    TRAFFIC_CONTROL = "traffic-control"
    BUS_STOP = "bus-stop"
    KIOSK = "kiosk"


# ============================================================================
# Main Model
# ============================================================================

class HsProfileModel(BaseModel):
    """
    Pydantic model for wireless_controller/hotspot20/hs_profile configuration.
    
    Configure hotspot profile.
    
    Validation Rules:        - name: max_length=35 pattern=        - release: min=1 max=3 pattern=        - access_network_type: pattern=        - access_network_internet: pattern=        - access_network_asra: pattern=        - access_network_esr: pattern=        - access_network_uesa: pattern=        - venue_group: pattern=        - venue_type: pattern=        - hessid: pattern=        - proxy_arp: pattern=        - l2tif: pattern=        - pame_bi: pattern=        - anqp_domain_id: min=0 max=65535 pattern=        - domain_name: max_length=255 pattern=        - osu_ssid: max_length=255 pattern=        - gas_comeback_delay: min=100 max=10000 pattern=        - gas_fragmentation_limit: min=512 max=4096 pattern=        - dgaf: pattern=        - deauth_request_timeout: min=30 max=120 pattern=        - wnm_sleep_mode: pattern=        - bss_transition: pattern=        - venue_name: max_length=35 pattern=        - venue_url: max_length=35 pattern=        - roaming_consortium: max_length=35 pattern=        - nai_realm: max_length=35 pattern=        - oper_friendly_name: max_length=35 pattern=        - oper_icon: max_length=35 pattern=        - advice_of_charge: max_length=35 pattern=        - osu_provider_nai: max_length=35 pattern=        - terms_and_conditions: max_length=35 pattern=        - osu_provider: pattern=        - wan_metrics: max_length=35 pattern=        - network_auth: max_length=35 pattern=        - _3gpp_plmn: max_length=35 pattern=        - conn_cap: max_length=35 pattern=        - qos_map: max_length=35 pattern=        - ip_addr_type: max_length=35 pattern=        - wba_open_roaming: pattern=        - wba_financial_clearing_provider: max_length=127 pattern=        - wba_data_clearing_provider: max_length=127 pattern=        - wba_charging_currency: max_length=3 pattern=        - wba_charging_rate: min=0 max=4294967295 pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=35, default=None, description="Hotspot profile name.")    
    release: int | None = Field(ge=1, le=3, default=2, description="Hotspot 2.0 Release number (1, 2, 3, default = 2).")    
    access_network_type: HsProfileAccessNetworkTypeEnum | None = Field(default=HsProfileAccessNetworkTypeEnum.PRIVATE_NETWORK, description="Access network type.")    
    access_network_internet: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable connectivity to the Internet.")    
    access_network_asra: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable additional step required for access (ASRA).")    
    access_network_esr: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable emergency services reachable (ESR).")    
    access_network_uesa: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable unauthenticated emergency service accessible (UESA).")    
    venue_group: HsProfileVenueGroupEnum | None = Field(default=HsProfileVenueGroupEnum.UNSPECIFIED, description="Venue group.")    
    venue_type: HsProfileVenueTypeEnum | None = Field(default=HsProfileVenueTypeEnum.UNSPECIFIED, description="Venue type.")    
    hessid: str | None = Field(default="00:00:00:00:00:00", description="Homogeneous extended service set identifier (HESSID).")    
    proxy_arp: Literal["enable", "disable"] | None = Field(default="enable", description="Enable/disable Proxy ARP.")    
    l2tif: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable Layer 2 traffic inspection and filtering.")    
    pame_bi: Literal["disable", "enable"] | None = Field(default="enable", description="Enable/disable Pre-Association Message Exchange BSSID Independent (PAME-BI).")    
    anqp_domain_id: int | None = Field(ge=0, le=65535, default=0, description="ANQP Domain ID (0-65535).")    
    domain_name: str | None = Field(max_length=255, default=None, description="Domain name.")    
    osu_ssid: str | None = Field(max_length=255, default=None, description="Online sign up (OSU) SSID.")    
    gas_comeback_delay: int | None = Field(ge=100, le=10000, default=500, description="GAS comeback delay (0 or 100 - 10000 milliseconds, default = 500).")    
    gas_fragmentation_limit: int | None = Field(ge=512, le=4096, default=1024, description="GAS fragmentation limit (512 - 4096, default = 1024).")    
    dgaf: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable downstream group-addressed forwarding (DGAF).")    
    deauth_request_timeout: int | None = Field(ge=30, le=120, default=60, description="Deauthentication request timeout (in seconds).")    
    wnm_sleep_mode: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable wireless network management (WNM) sleep mode.")    
    bss_transition: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable basic service set (BSS) transition Support.")    
    venue_name: str | None = Field(max_length=35, default=None, description="Venue name.")  # datasource: ['wireless-controller.hotspot20.anqp-venue-name.name']    
    venue_url: str | None = Field(max_length=35, default=None, description="Venue name.")  # datasource: ['wireless-controller.hotspot20.anqp-venue-url.name']    
    roaming_consortium: str | None = Field(max_length=35, default=None, description="Roaming consortium list name.")  # datasource: ['wireless-controller.hotspot20.anqp-roaming-consortium.name']    
    nai_realm: str | None = Field(max_length=35, default=None, description="NAI realm list name.")  # datasource: ['wireless-controller.hotspot20.anqp-nai-realm.name']    
    oper_friendly_name: str | None = Field(max_length=35, default=None, description="Operator friendly name.")  # datasource: ['wireless-controller.hotspot20.h2qp-operator-name.name']    
    oper_icon: str | None = Field(max_length=35, default=None, description="Operator icon.")  # datasource: ['wireless-controller.hotspot20.icon.name']    
    advice_of_charge: str | None = Field(max_length=35, default=None, description="Advice of charge.")  # datasource: ['wireless-controller.hotspot20.h2qp-advice-of-charge.name']    
    osu_provider_nai: str | None = Field(max_length=35, default=None, description="OSU Provider NAI.")  # datasource: ['wireless-controller.hotspot20.h2qp-osu-provider-nai.name']    
    terms_and_conditions: str | None = Field(max_length=35, default=None, description="Terms and conditions.")  # datasource: ['wireless-controller.hotspot20.h2qp-terms-and-conditions.name']    
    osu_provider: list[HsProfileOsuProvider] = Field(default_factory=list, description="Manually selected list of OSU provider(s).")    
    wan_metrics: str | None = Field(max_length=35, default=None, description="WAN metric name.")  # datasource: ['wireless-controller.hotspot20.h2qp-wan-metric.name']    
    network_auth: str | None = Field(max_length=35, default=None, description="Network authentication name.")  # datasource: ['wireless-controller.hotspot20.anqp-network-auth-type.name']    
    _3gpp_plmn: str | None = Field(max_length=35, default=None, serialization_alias="3gpp-plmn", description="3GPP PLMN name.")  # datasource: ['wireless-controller.hotspot20.anqp-3gpp-cellular.name']    
    conn_cap: str | None = Field(max_length=35, default=None, description="Connection capability name.")  # datasource: ['wireless-controller.hotspot20.h2qp-conn-capability.name']    
    qos_map: str | None = Field(max_length=35, default=None, description="QoS MAP set ID.")  # datasource: ['wireless-controller.hotspot20.qos-map.name']    
    ip_addr_type: str | None = Field(max_length=35, default=None, description="IP address type name.")  # datasource: ['wireless-controller.hotspot20.anqp-ip-address-type.name']    
    wba_open_roaming: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable WBA open roaming support.")    
    wba_financial_clearing_provider: str | None = Field(max_length=127, default=None, description="WBA ID of financial clearing provider.")    
    wba_data_clearing_provider: str | None = Field(max_length=127, default=None, description="WBA ID of data clearing provider.")    
    wba_charging_currency: str | None = Field(max_length=3, default=None, description="Three letter currency code.")    
    wba_charging_rate: int | None = Field(ge=0, le=4294967295, default=0, description="Number of currency units per kilobyte.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    @field_validator('venue_name')
    @classmethod
    def validate_venue_name(cls, v: Any) -> Any:
        """
        Validate venue_name field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-venue-name.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('venue_url')
    @classmethod
    def validate_venue_url(cls, v: Any) -> Any:
        """
        Validate venue_url field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-venue-url.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('roaming_consortium')
    @classmethod
    def validate_roaming_consortium(cls, v: Any) -> Any:
        """
        Validate roaming_consortium field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-roaming-consortium.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('nai_realm')
    @classmethod
    def validate_nai_realm(cls, v: Any) -> Any:
        """
        Validate nai_realm field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-nai-realm.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('oper_friendly_name')
    @classmethod
    def validate_oper_friendly_name(cls, v: Any) -> Any:
        """
        Validate oper_friendly_name field.
        
        Datasource: ['wireless-controller.hotspot20.h2qp-operator-name.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('oper_icon')
    @classmethod
    def validate_oper_icon(cls, v: Any) -> Any:
        """
        Validate oper_icon field.
        
        Datasource: ['wireless-controller.hotspot20.icon.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('advice_of_charge')
    @classmethod
    def validate_advice_of_charge(cls, v: Any) -> Any:
        """
        Validate advice_of_charge field.
        
        Datasource: ['wireless-controller.hotspot20.h2qp-advice-of-charge.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('osu_provider_nai')
    @classmethod
    def validate_osu_provider_nai(cls, v: Any) -> Any:
        """
        Validate osu_provider_nai field.
        
        Datasource: ['wireless-controller.hotspot20.h2qp-osu-provider-nai.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('terms_and_conditions')
    @classmethod
    def validate_terms_and_conditions(cls, v: Any) -> Any:
        """
        Validate terms_and_conditions field.
        
        Datasource: ['wireless-controller.hotspot20.h2qp-terms-and-conditions.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('wan_metrics')
    @classmethod
    def validate_wan_metrics(cls, v: Any) -> Any:
        """
        Validate wan_metrics field.
        
        Datasource: ['wireless-controller.hotspot20.h2qp-wan-metric.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('network_auth')
    @classmethod
    def validate_network_auth(cls, v: Any) -> Any:
        """
        Validate network_auth field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-network-auth-type.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('_3gpp_plmn')
    @classmethod
    def validate__3gpp_plmn(cls, v: Any) -> Any:
        """
        Validate _3gpp_plmn field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-3gpp-cellular.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('conn_cap')
    @classmethod
    def validate_conn_cap(cls, v: Any) -> Any:
        """
        Validate conn_cap field.
        
        Datasource: ['wireless-controller.hotspot20.h2qp-conn-capability.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('qos_map')
    @classmethod
    def validate_qos_map(cls, v: Any) -> Any:
        """
        Validate qos_map field.
        
        Datasource: ['wireless-controller.hotspot20.qos-map.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    @field_validator('ip_addr_type')
    @classmethod
    def validate_ip_addr_type(cls, v: Any) -> Any:
        """
        Validate ip_addr_type field.
        
        Datasource: ['wireless-controller.hotspot20.anqp-ip-address-type.name']
        
        Note:
            This validator only checks basic constraints.
            To validate that referenced object exists, query the API.
        """
        # Basic validation passed via Field() constraints
        # Additional datasource validation could be added here
        return v    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "HsProfileModel":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)
    # ========================================================================
    # Datasource Validation Methods
    # ========================================================================    
    async def validate_venue_name_references(self, client: Any) -> list[str]:
        """
        Validate venue_name references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-venue-name        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     venue_name="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_venue_name_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "venue_name", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_venue_name.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Venue-Name '{value}' not found in "
                "wireless-controller/hotspot20/anqp-venue-name"
            )        
        return errors    
    async def validate_venue_url_references(self, client: Any) -> list[str]:
        """
        Validate venue_url references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-venue-url        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     venue_url="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_venue_url_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "venue_url", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_venue_url.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Venue-Url '{value}' not found in "
                "wireless-controller/hotspot20/anqp-venue-url"
            )        
        return errors    
    async def validate_roaming_consortium_references(self, client: Any) -> list[str]:
        """
        Validate roaming_consortium references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-roaming-consortium        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     roaming_consortium="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_roaming_consortium_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "roaming_consortium", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_roaming_consortium.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Roaming-Consortium '{value}' not found in "
                "wireless-controller/hotspot20/anqp-roaming-consortium"
            )        
        return errors    
    async def validate_nai_realm_references(self, client: Any) -> list[str]:
        """
        Validate nai_realm references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-nai-realm        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     nai_realm="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_nai_realm_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "nai_realm", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_nai_realm.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Nai-Realm '{value}' not found in "
                "wireless-controller/hotspot20/anqp-nai-realm"
            )        
        return errors    
    async def validate_oper_friendly_name_references(self, client: Any) -> list[str]:
        """
        Validate oper_friendly_name references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-operator-name        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     oper_friendly_name="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_oper_friendly_name_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "oper_friendly_name", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.h2qp_operator_name.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Oper-Friendly-Name '{value}' not found in "
                "wireless-controller/hotspot20/h2qp-operator-name"
            )        
        return errors    
    async def validate_oper_icon_references(self, client: Any) -> list[str]:
        """
        Validate oper_icon references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/icon        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     oper_icon="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_oper_icon_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "oper_icon", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.icon.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Oper-Icon '{value}' not found in "
                "wireless-controller/hotspot20/icon"
            )        
        return errors    
    async def validate_advice_of_charge_references(self, client: Any) -> list[str]:
        """
        Validate advice_of_charge references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-advice-of-charge        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     advice_of_charge="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_advice_of_charge_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "advice_of_charge", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.h2qp_advice_of_charge.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Advice-Of-Charge '{value}' not found in "
                "wireless-controller/hotspot20/h2qp-advice-of-charge"
            )        
        return errors    
    async def validate_osu_provider_nai_references(self, client: Any) -> list[str]:
        """
        Validate osu_provider_nai references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-osu-provider-nai        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     osu_provider_nai="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_osu_provider_nai_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "osu_provider_nai", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.h2qp_osu_provider_nai.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Osu-Provider-Nai '{value}' not found in "
                "wireless-controller/hotspot20/h2qp-osu-provider-nai"
            )        
        return errors    
    async def validate_terms_and_conditions_references(self, client: Any) -> list[str]:
        """
        Validate terms_and_conditions references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-terms-and-conditions        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     terms_and_conditions="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_terms_and_conditions_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "terms_and_conditions", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.h2qp_terms_and_conditions.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Terms-And-Conditions '{value}' not found in "
                "wireless-controller/hotspot20/h2qp-terms-and-conditions"
            )        
        return errors    
    async def validate_osu_provider_references(self, client: Any) -> list[str]:
        """
        Validate osu_provider references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-osu-provider        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     osu_provider=[{"name": "invalid-name"}],
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_osu_provider_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate child table items
        values = getattr(self, "osu_provider", [])
        if not values:
            return errors
        
        for item in values:
            if isinstance(item, dict):
                value = item.get("name")
            else:
                value = getattr(item, "name", None)
            
            if not value:
                continue
            
            # Check all datasource endpoints
            found = False
            if await client.api.cmdb.wireless_controller.hotspot20.h2qp_osu_provider.exists(value):
                found = True
            
            if not found:
                errors.append(
                    f"Osu-Provider '{value}' not found in "
                    "wireless-controller/hotspot20/h2qp-osu-provider"
                )        
        return errors    
    async def validate_wan_metrics_references(self, client: Any) -> list[str]:
        """
        Validate wan_metrics references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-wan-metric        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     wan_metrics="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_wan_metrics_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "wan_metrics", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.h2qp_wan_metric.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Wan-Metrics '{value}' not found in "
                "wireless-controller/hotspot20/h2qp-wan-metric"
            )        
        return errors    
    async def validate_network_auth_references(self, client: Any) -> list[str]:
        """
        Validate network_auth references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-network-auth-type        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     network_auth="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_network_auth_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "network_auth", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_network_auth_type.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Network-Auth '{value}' not found in "
                "wireless-controller/hotspot20/anqp-network-auth-type"
            )        
        return errors    
    async def validate_3gpp_plmn_references(self, client: Any) -> list[str]:
        """
        Validate 3gpp_plmn references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-3gpp-cellular        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     3gpp_plmn="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_3gpp_plmn_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "3gpp_plmn", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_3gpp_cellular.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"3Gpp-Plmn '{value}' not found in "
                "wireless-controller/hotspot20/anqp-3gpp-cellular"
            )        
        return errors    
    async def validate_conn_cap_references(self, client: Any) -> list[str]:
        """
        Validate conn_cap references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/h2qp-conn-capability        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     conn_cap="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_conn_cap_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "conn_cap", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.h2qp_conn_capability.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Conn-Cap '{value}' not found in "
                "wireless-controller/hotspot20/h2qp-conn-capability"
            )        
        return errors    
    async def validate_qos_map_references(self, client: Any) -> list[str]:
        """
        Validate qos_map references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/qos-map        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     qos_map="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_qos_map_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "qos_map", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.qos_map.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Qos-Map '{value}' not found in "
                "wireless-controller/hotspot20/qos-map"
            )        
        return errors    
    async def validate_ip_addr_type_references(self, client: Any) -> list[str]:
        """
        Validate ip_addr_type references exist in FortiGate.
        
        This method checks if referenced objects exist by calling exists() on
        the appropriate API endpoints. This is an OPTIONAL validation step that
        can be called before posting to the API to catch reference errors early.
        
        Datasource endpoints checked:
        - wireless-controller/hotspot20/anqp-ip-address-type        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of validation error messages (empty if all valid)
            
        Example:
            >>> from hfortix_fortios import FortiOS
            >>> 
            >>> fgt = FortiOS(host="192.168.1.1", token="your-token")
            >>> policy = HsProfileModel(
            ...     ip_addr_type="invalid-name",
            ... )
            >>> 
            >>> # Validate before posting
            >>> errors = await policy.validate_ip_addr_type_references(fgt._client)
            >>> if errors:
            ...     print("Validation failed:", errors)
            ... else:
            ...     result = await fgt.api.cmdb.wireless_controller.hotspot20.hs_profile.post(policy.to_fortios_dict())
        """
        errors: list[str] = []
        
        # Validate scalar field
        value = getattr(self, "ip_addr_type", None)
        if not value:
            return errors
        
        # Check all datasource endpoints
        found = False
        if await client.api.cmdb.wireless_controller.hotspot20.anqp_ip_address_type.exists(value):
            found = True
        
        if not found:
            errors.append(
                f"Ip-Addr-Type '{value}' not found in "
                "wireless-controller/hotspot20/anqp-ip-address-type"
            )        
        return errors    
    async def validate_all_references(self, client: Any) -> list[str]:
        """
        Validate ALL datasource references in this model.
        
        Convenience method that runs all validate_*_references() methods
        and aggregates the results.
        
        Args:
            client: FortiOS client instance (from fgt._client)
            
        Returns:
            List of all validation errors found
            
        Example:
            >>> errors = await policy.validate_all_references(fgt._client)
            >>> if errors:
            ...     for error in errors:
            ...         print(f"  - {error}")
        """
        all_errors = []
        
        errors = await self.validate_venue_name_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_venue_url_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_roaming_consortium_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_nai_realm_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_oper_friendly_name_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_oper_icon_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_advice_of_charge_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_osu_provider_nai_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_terms_and_conditions_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_osu_provider_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_wan_metrics_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_network_auth_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_3gpp_plmn_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_conn_cap_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_qos_map_references(client)
        all_errors.extend(errors)        
        errors = await self.validate_ip_addr_type_references(client)
        all_errors.extend(errors)        
        return all_errors

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "HsProfileModel",    "HsProfileOsuProvider",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.2
# Generated: 2026-01-21T16:23:59.498784Z
# ============================================================================